from setuptools import setup

setup(
   name='nfem',
   version='0.1',
   description='',
   author='Thomas Oberbichler',
   author_email='thomas.oberbichler@gmail.com',
   packages=['nfem'],
   install_requires=['numpy', 'plotly'],
)
